@@ -137,10 +137,11 @@ score.zipregs <- function(y, x, logged = FALSE) {
 
 
 #[export]
-negbin.regs <- function (y, x, tol = 1e-07, logged = FALSE, parallel = FALSE, maxiters = 100) {
-  mod <- .Call(Rfast2_negbin_regs, y, x, tol, maxiters, parallel)$info
-  ini <- Rfast::negbin.mle(y)$loglik
+negbin.regs <- function (y, x, type = 1, tol = 1e-07, logged = FALSE, parallel = FALSE, maxiters = 100) {
+  mod <- .Call("Rfast2_negbin_regs", y, x, tol, maxiters, parallel)$info
+  ini <- Rfast::negbin.mle(y, type = type)$loglik
   stat <- 2 * (mod - ini)
   pvalue <- pchisq(stat, 1, lower.tail = FALSE, log.p = logged)
-  cbind(stat, pvalue)
+  res <- cbind(stat, pvalue)
+  colnames(res) <- c("stat", "p-value")
 }
